==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.get_x5 = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_zk = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zk", {
        get: function () {
            return this.get_zk();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_zb = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.bj = function () {
        return new MarketFacilitationIndexIndicator();
    };
    MarketFacilitationIndexIndicator.prototype.get_aax = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_acc = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "acc", {
        get: function () {
            return this.get_acc();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_ab3 = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };
